#
# spec file for package kismet
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%ifarch %{ix86} x86_64
%bcond_with ubertooth
%endif

%define realver 2023-07-R1
Name:           kismet
Version:        2023_07_R1
Release:        3.5
Summary:        An 802.11 Wireless Network Sniffer
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Diagnostic
URL:            https://www.kismetwireless.net/
#Git-Clone:     https://github.com/kismetwireless/kismet.git
Source:         https://github.com/kismetwireless/kismet/archive/%{name}-%{realver}.tar.gz
Source2:        %{name}.sysusers
Patch0:         kismet-fix-build.patch
Patch1:         harden_kismet.service.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libcap-devel
BuildRequires:  libpcap-devel
BuildRequires:  libsensors4-devel
BuildRequires:  memory-constraints
BuildRequires:  pkgconfig
BuildRequires:  protobuf-c
BuildRequires:  python3
BuildRequires:  python3-setuptools
BuildRequires:  sysuser-shadow
BuildRequires:  sysuser-tools
BuildRequires:  pkgconfig(libnl-3.0) >= 3.0
BuildRequires:  pkgconfig(libnm)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(libprotobuf-c)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(libwebsockets) >= 3.2.0
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(zlib)
%if 0%{with ubertooth}
BuildRequires:  libbtbb-devel
BuildRequires:  ubertooth-devel
%endif
Recommends:     kismet-capture-bt-geiger
Recommends:     kismet-capture-freaklabs-zigbee
Recommends:     kismet-capture-linux-bluetooth
Recommends:     kismet-capture-linux-wifi
Recommends:     kismet-capture-nrf-51822
Recommends:     kismet-capture-nrf-52840
Recommends:     kismet-capture-nrf-mousejack
Recommends:     kismet-capture-rz-killerbee
Recommends:     kismet-capture-sdr-rtl433
Recommends:     kismet-capture-sdr-rtladsb
Recommends:     kismet-capture-sdr-rtlamr
Recommends:     kismet-capture-ti-cc2540
Recommends:     kismet-logtools
Requires(pre):  %{name}-common = %{version}
Requires(pre):  permissions
Requires(pre):  shadow
%if 0%{with ubertooth}
Recommends:     kismet-capture-ubertooth-one
%endif
%{?systemd_ordering}

%global homedir %{_localstatedir}/lib/%{name}

%description
Kismet is a wireless network and device detector, sniffer, wardriving
tool, and WIDS (wireless intrusion detection) framework.

Kismet works with Wi-Fi interfaces, Bluetooth interfaces, some
SDR (software defined radio) hardware like the RTLSDR, and other
specialized capture hardware.

%package common
Summary:        Shared data for Kismet and its plug-ins
Group:          Productivity/Networking/Diagnostic
BuildArch:      noarch
Provides:       group(kismet)
Provides:       user(kismet)
%{?sysusers_requires}

%description common
Kismet is a wireless network and device detector, sniffer, wardriving
tool, and WIDS (wireless intrusion detection) framework.

This subpackage sets up the system user/group for the rest of Kismet.

%package logtools
Summary:        Kismet logtools
Group:          Productivity/Networking/Diagnostic
Requires:       kismet = %{version}

%description logtools
Kismet is a wireless network and device detector, sniffer, wardriving
tool, and WIDS (wireless intrusion detection) framework.

This subpackage contains several kismetdb log tools
 - kismetdb_dump_devices
 - kismetdb_statistics
 - kismetdb_strip_packets
 - kismetdb_to_kml
 - kismetdb_to_wiglecsv

%package capture-linux-bluetooth
Summary:        Kismet Linux Bluetooth capture helper
Group:          Productivity/Networking/Diagnostic
BuildRequires:  group(kismet)
Requires(pre):  group(kismet)
Requires(pre):  %{name}-common = %{version}
Requires(pre):  permissions

%description capture-linux-bluetooth
Kismet is a wireless network and device detector, sniffer, wardriving
tool, and WIDS (wireless intrusion detection) framework.

This subpackage contains Kismet Linux Bluetooth capture helper.

%package capture-linux-wifi
Summary:        Kismet Linux WiFi capture helper
Group:          Productivity/Networking/Diagnostic
BuildRequires:  group(kismet)
Requires(pre):  group(kismet)
Requires(pre):  %{name}-common = %{version}
Requires(pre):  permissions

%description capture-linux-wifi
Kismet is a wireless network and device detector, sniffer, wardriving
tool, and WIDS (wireless intrusion detection) framework.

This subpackage contains Kismet Linux WiFi capture helper.

%package capture-sdr-rtl433
Summary:        Kismet SDR rtl433 capture helper
Group:          Productivity/Networking/Diagnostic
Requires:       python3-protobuf >= 3.0.0
Requires:       python3-websockets
Requires:       rtl_433
BuildArch:      noarch

%description capture-sdr-rtl433
Kismet is a wireless network and device detector, sniffer, wardriving
tool, and WIDS (wireless intrusion detection) framework.

This subpackage contains Kismet SDR rtl433 capture helper.
https://kismetwireless.net/docs/readme/datasources_sdr_rtl433/

%package capture-sdr-rtlamr
Summary:        Kismet SDR rtlamr capture helper
Group:          Productivity/Networking/Diagnostic
Requires:       python3-numpy
Requires:       python3-protobuf >= 3.0.0
Requires:       python3-websockets
Recommends:     rtl_amr
BuildArch:      noarch

%description capture-sdr-rtlamr
Kismet is a wireless network and device detector, sniffer, wardriving
tool, and WIDS (wireless intrusion detection) framework.

This subpackage contains Kismet SDR rtlamr capture helper.
https://kismetwireless.net/docs/readme/datasources_sdr_rtlamr/

%package capture-sdr-rtladsb
Summary:        Kismet SDR rtladsb capture helper
Group:          Productivity/Networking/Diagnostic
Requires:       python3-numpy
Requires:       python3-protobuf >= 3.0.0
Requires:       python3-websockets
Requires:       rtl-sdr
BuildArch:      noarch

%description capture-sdr-rtladsb
Kismet is a wireless network and device detector, sniffer, wardriving
tool, and WIDS (wireless intrusion detection) framework.

This subpackage contains the SDR rtladsb capture helper.
https://kismetwireless.net/docs/readme/datasources_sdr_rtladsb/

%package capture-nrf-mousejack
Summary:        Kismet nRF MouseJack capture helper
Group:          Productivity/Networking/Diagnostic
Requires:       kismet = %{version}

%description capture-nrf-mousejack
Kismet is a wireless network and device detector, sniffer, wardriving
tool, and WIDS (wireless intrusion detection) framework.

This subpackage contains the nRF MouseJack capture helper.
https://kismetwireless.net/docs/readme/datasources_nrf_mousejack/

%package capture-rz-killerbee
Summary:        Kismet Killerbee Sniffer capture helper
Group:          Productivity/Networking/Diagnostic
Requires:       kismet = %{version}

%description capture-rz-killerbee
Kismet is a wireless network and device detector, sniffer, wardriving
tool, and WIDS (wireless intrusion detection) framework.

This subpackage contains the Killerbee Sniffer capture helper.

%package capture-freaklabs-zigbee
Summary:        Kismet Freaklabs Zigbee capture helper
Group:          Productivity/Networking/Diagnostic
Requires:       python3-protobuf >= 3.0.0
Requires:       python3-pyserial
BuildArch:      noarch

%description capture-freaklabs-zigbee
Kismet is a wireless network and device detector, sniffer, wardriving
tool, and WIDS (wireless intrusion detection) framework.

This subpackage contains the Freaklabs Zigbee capture helper.

%package capture-ti-cc2540
Summary:        Kismet TI CC2540 (BTLE) capture helper
Group:          Productivity/Networking/Diagnostic

%description capture-ti-cc2540
Kismet is a wireless network and device detector, sniffer, wardriving
tool, and WIDS (wireless intrusion detection) framework.

This subpackage contains the Texas Instruments CC2540 BTLE capture
helper.

%package capture-ti-cc-2531
Summary:        Kismet TICC2531 802.15.4 Zigbee Sniffer capture helper
Group:          Productivity/Networking/Diagnostic

%description capture-ti-cc-2531
Kismet is a wireless network and device detector, sniffer, wardriving
tool, and WIDS (wireless intrusion detection) framework.

This subpackage contains the Texas Instruments  TICC2531 802.15.4
Zigbee Sniffer capture helper.

%package capture-nrf-51822
Summary:        Kismet nRF 51822 (BTLE) capture helper
Group:          Productivity/Networking/Diagnostic

%description capture-nrf-51822
Kismet is a wireless network and device detector, sniffer, wardriving
tool, and WIDS (wireless intrusion detection) framework.

This subpackage contains the nRF 51822 BTLE capture helper.

%package capture-nrf-52840
Summary:        Kismet nRF 52840 (BTLE) capture helper
Group:          Productivity/Networking/Diagnostic

%description capture-nrf-52840
Kismet is a wireless network and device detector, sniffer, wardriving
tool, and WIDS (wireless intrusion detection) framework.

This subpackage contains the nRF 52840 BTLE capture helper.

%package capture-nrf-nxp-kw41z
Summary:        Kismet NXP KW41Z BTLE and Zigbee Sniffer capture helper
Group:          Productivity/Networking/Diagnostic

%description capture-nrf-nxp-kw41z
Kismet is a wireless network and device detector, sniffer, wardriving
tool, and WIDS (wireless intrusion detection) framework.

This subpackage contains the NXP KW41Z BTLE and Zigbee Sniffer capture
helper.

%package capture-bt-geiger
Summary:        Kismet BTLE geiger counter capture helper
Group:          Productivity/Networking/Diagnostic
BuildArch:      noarch

%description capture-bt-geiger
Kismet is a wireless network and device detector, sniffer, wardriving
tool, and WIDS (wireless intrusion detection) framework.

This subpackage contains the BTLE geiger counter capture helper.

%if 0%{with ubertooth}
%package capture-ubertooth-one
Summary:        Kismet Ubertooth One (BTLE) capture helper
Group:          Productivity/Networking/Diagnostic

%description capture-ubertooth-one
Kismet is a wireless network and device detector, sniffer, wardriving
tool, and WIDS (wireless intrusion detection) framework.

This subpackage contains the Ubertooth One (BTLE) capture helper.
%endif

%package devel
Summary:        Development files for kismet
Group:          Development/Libraries/C and C++
Requires:       kismet = %{version}

%description devel
Kismet is a wireless network and device detector, sniffer, wardriving
tool, and WIDS (wireless intrusion detection) framework.

This subpackage contains files files for developing applications that
want to make use of kismet.

%prep
%setup -q -n kismet-kismet-%{realver}
%patch -P 0 -p1
# HACK: Add python DESTDIR support for python stuff
find . -type f -name "Makefile*" -exec sed -i 's|setup.py install|setup.py install --root=$(DESTDIR)|g' {} \;
# Fix wrong-script-end-of-line-encoding
sed -i 's/\r$//' http_data/css/layout.css
# rpmlint will complain about missing shebangs otherwise
chmod a-x http_data/css/*.css
%patch -P 1 -p1

%build
%limit_build -m 2500
%configure \
    --sysconfdir=%{_sysconfdir}/kismet \
    --enable-btgeiger \
    --disable-wifi-coconut \
    --disable-optimization
make %{?_smp_mflags} all
make %{?_smp_mflags} plugins

%sysusers_generate_pre %{SOURCE2} %{name} %{name}.conf

%install
export INSTUSR=`id -un`
export INSTGRP=`id -gn`
export MANGRP=`id -gn`
export SUIDGROUP=`id -gn`
export SUID="no"
%make_install -e
install -D -m 0644 packaging/systemd/kismet.service %{buildroot}%{_unitdir}/%{name}.service
install -d %{buildroot}%{_sbindir}
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
install -D -m 644 %{SOURCE2} %{buildroot}%{_sysusersdir}/%{name}.conf
# kismet home dir
install -m 750 -d %{buildroot}%{homedir}
# kismet systemwide plugin dir
install -d %{buildroot}%{_libdir}/kismet/
# install kismet plugins
install -D plugin-alertsyslog/alertsyslog.so %{buildroot}%{_libdir}/kismet/alertsyslog.so
%fdupes -s %{buildroot}%{_datadir}/kismet

%pre
%service_add_pre %{name}.service

%pre common -f %{name}.pre

%preun
%service_del_preun %{name}.service

%post
%service_add_post %{name}.service

%post capture-linux-bluetooth
%set_permissions %{_bindir}/kismet_cap_linux_bluetooth

%post capture-linux-wifi
%set_permissions %{_bindir}/kismet_cap_linux_wifi

%postun
%service_del_postun %{name}.service

%verifyscript capture-linux-bluetooth
%verify_permissions -e %{_bindir}/kismet_cap_linux_bluetooth

%verifyscript capture-linux-wifi
%verify_permissions -e %{_bindir}/kismet_cap_linux_wifi

%files
%license LICENSE
%doc README.md README.OLD README.SSL
%dir %{_sysconfdir}/kismet
%config %{_sysconfdir}/kismet/kismet.conf
%config %{_sysconfdir}/kismet/kismet_80211.conf
%config %{_sysconfdir}/kismet/kismet_alerts.conf
%config %{_sysconfdir}/kismet/kismet_filter.conf
%config %{_sysconfdir}/kismet/kismet_httpd.conf
%config %{_sysconfdir}/kismet/kismet_logging.conf
%config %{_sysconfdir}/kismet/kismet_memory.conf
%config %{_sysconfdir}/kismet/kismet_uav.conf
%config %{_sysconfdir}/kismet/kismet_wardrive.conf
%{_bindir}/kismet
%{_bindir}/kismet_discovery
%{_bindir}/kismet_server
%{_bindir}/kismet_cap_kismetdb
%{_bindir}/kismet_cap_pcapfile
%dir %{_datadir}/kismet
%{_datadir}/kismet/kismet_adsb_icao.txt.gz
%{_datadir}/kismet/kismet_manuf.txt.gz
%{_datadir}/kismet/httpd
%{_unitdir}/%{name}.service
%{_sbindir}/rc%{name}
%dir %{_libdir}/kismet/
%{_libdir}/kismet/alertsyslog.so
#
%attr(750,%{name},%{name}) %dir %{homedir}
#

%files common
%{_sysusersdir}/%{name}.conf

%files logtools
%{_bindir}/kismetdb_clean
%{_bindir}/kismetdb_dump_devices
%{_bindir}/kismetdb_statistics
%{_bindir}/kismetdb_strip_packets
%{_bindir}/kismetdb_to_gpx
%{_bindir}/kismetdb_to_kml
%{_bindir}/kismetdb_to_pcap
%{_bindir}/kismetdb_to_wiglecsv

%files capture-linux-bluetooth
%verify(not mode caps) %attr(0750,root,kismet) %caps(cap_net_raw,cap_net_admin=ep) %{_bindir}/kismet_cap_linux_bluetooth

%files capture-linux-wifi
%verify(not mode caps) %attr(0750,root,kismet) %caps(cap_net_raw,cap_net_admin=ep) %{_bindir}/kismet_cap_linux_wifi

%files capture-nrf-mousejack
%{_bindir}/kismet_cap_nrf_mousejack

%files capture-rz-killerbee
%attr(755, root, -) %{_bindir}/kismet_cap_rz_killerbee

%files capture-freaklabs-zigbee
%{_bindir}/kismet_cap_freaklabs_zigbee
%{python3_sitelib}/KismetCaptureFreaklabsZigbee*

%files capture-sdr-rtladsb
%{_bindir}/kismet_cap_sdr_rtladsb
%{python3_sitelib}/KismetCaptureRtladsb*

%files capture-sdr-rtlamr
%{_bindir}/kismet_cap_sdr_rtlamr
%{python3_sitelib}/KismetCaptureRtlamr*

%files capture-sdr-rtl433
%{_bindir}/kismet_cap_sdr_rtl433
%{python3_sitelib}/KismetCaptureRtl433*

%files capture-ti-cc2540
%{_bindir}/kismet_cap_ti_cc_2540

%files  capture-ti-cc-2531
%{_bindir}/kismet_cap_ti_cc_2531

%files capture-nrf-51822
%{_bindir}/kismet_cap_nrf_51822

%files capture-nrf-52840
%{_bindir}/kismet_cap_nrf_52840

%files capture-nrf-nxp-kw41z
%{_bindir}/kismet_cap_nxp_kw41z

%files capture-bt-geiger
%{_bindir}/kismet_cap_bt_geiger
%{python3_sitelib}/KismetCaptureBtGeiger*

%if 0%{with ubertooth}
%files capture-ubertooth-one
%{_bindir}/kismet_cap_ubertooth_one
%endif

%files devel
%{_libdir}/pkgconfig/kismet.pc

%changelog
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Oct  9 2023 Marcus Meissner <meissner@suse.com>
- add the sysuser pre section to %%package common.
* Thu Jul 27 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 2023-07-R1
  * New dark mode in the web UI.
  * New page-based device list in the web UI.
  * The old device list was always slightly odd & could get in
    states where the JS did not update as expected. The new pager
    UI addresses this & brings a big performance boost.
  * Fixes to channel listing.
  * Fixes to remote capture in some situations.
  * Optimizations to the field tracking system.
  * Improvements and fixes to WiFi 6e channel processing and
    numbering.
  * Fixes and general improvements to the order of operations when
    configuring WiFi interfaces on Linux for monitor mode.
  * Inclusion of the Hak5 WiFi Coconut userspace drivers and
    capture.
  * Transition to using emphemeral JWT signing for login management
    instead of a state file.
  * Increased live censorship in the Web UI when ?censor=1 is
    passed.
  * Fixes to Python-based websockets not loading SSL contexts.
    Upgrade a number of internal libraries for the Web UI and
    internals.
  * New graphing libraries.
  * New datatables version.
  * New robinhood hash.
  * Upgraded font-awesome.
  * Upgraded libfmt.
  * New moodycamel queue.
  * Fix long-standing bugs with field selection and summary in the
    API requests.
  * Add new display of thermal state on supported systems (linux).
  * Revamp how rtl433 devices are mapped, split into
    sensors/meters/etc.
  * Handle power meter via rtl433.
  * Revamp sensor/meter UI to carry much more informaiton.
  * Revamp IO system loops and locking patterns entirely to address
    hangs in some situations.
  * Add packet id and checksumming to pcap-ng exports.
  * Fix linux-capture-wifi following symlinks in /tmp.
  * Better NMEA handling.
  * Support libpcre2 now that pcre1 is deprecated.
  * Massive speed improvements in packet processing due to removal
    of dissection chain chokepoints.
  * Revamp of packet de-duplicaton system.
  * Add tx/rx packet counts per device.
* Wed Mar  1 2023 Wolfgang Frisch <wolfgang.frisch@suse.com>
- Packaging:
  * Move systemd-sysusers config to a common subpackage.
  * Separate %%post and %%verify sections for each package.
  * Set %%noarch for a number of subpackages.
* Thu Jan 26 2023 Wolfgang Frisch <wolfgang.frisch@suse.com>
- Drop unnecessary root privileges in the systemd unit (bsc#1207654).
  * switch from old-style user/group mgmt to sysusers.
- Disable overly strict hardenings that would break some capture binaries,
  e.g. kismet_cap_linux_wifi.
- Remove superfluous executable bits from CSS files.
* Tue Jan  3 2023 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_kismet.service.patch
* Wed Aug 17 2022 Dirk Müller <dmueller@suse.com>
- update to 2022-08-R1:
  * Initial support for Wi-Fi 6e support
    6GHz channels now have initial support, and can be captured from. 6e APs will
    show up in Kismet, but currently the UI won’t classify them quite right.
    For Intel based 6e cards, you must run iw dev <xyz> scan before starting
    Kismet! Intel ignores the regdb and will only enable 6GHz channels after a
    scan!
    For other cards, you must set the regdomain to US via iw reg set US.
  * GPS magnetic heading support on hardware which provides it
  * New graph line in packets UI showing the packets per second processed
  * New BPF filter programs for wardrive and remote capture mode
  * Fix 802.11r records not being initialized which could cause a crash
  * Initial support for modern droneID v2 data
  * Lots of performance improvements
* Tue Jun 21 2022 Martin Hauke <mardnh@gmx.de>
- Add missing Requires: python-websockets
- Use setcap (group kismet) for the capture binaries
  * kismet_cap_linux_wifi
  * kismet_cap_linux_bluetooth
* Fri Feb 11 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2022-02-R1
  This is primarily a maintenance release to fix a number of bugs
  discovered in the 2022-01 releases, including:
  * Some datasources not appearing on arm32 (rpi)
  * Fix segfault due to “smart” pointers and legacy api
  * Check for zero-sized broken frames
  * Give IE127 alerts a little more headroom
  * Fix override config append not appending
  * Merge patch to trim GPS coordinates in logs
  * Fix old mutex in datasource serialization
  * Detect binary in NMEA GPS streams
* Thu Feb  3 2022 Andreas Schwab <schwab@suse.de>
- Limit parallelism to avoid running out of memory
* Fri Jan 28 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2022-01-R3a
  * Install missing kismet_wardrive.conf
* Fri Jan 28 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2022-01-R3
  * Minor fixes on top of 2022-01-R1 and 2022-01-R2
  * Fixing compilation on some old compilers and distributions
  * Fixing a javascript race condition that caused some of the
    tabs in the UI to not appear sometimes.
* Fri Jan 21 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2022-01-R2
  * Fix alert-syslog plugin
  * Remove outdated docs
  * Fix webserver stall
  * Add regex to the devices view-by-time endpoint
- Drop patch:
  * 0001-Update-FetchGlobal-usage.patch
* Wed Jan 19 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2022-01-R1
  New features
  * Significantly reduced RAM requirements
  * Additional packet tags
  * Additional eventbus events
  * New packet deduplication system
  * More info in the UI
  * Show more collected information in the UI, like GPScoordinates
    per SSID.
  * Better column alignment in the UI
  * Columns in the main device list are now better formatted and
    aligned, with right-aligned numeric columns and proper
    scrolling of the headers.
  * Able to disable sources in the UI
  * More log filtering
  * Direct Wigle logging
  * Direct logging to Wigle CSV format.
  * Wardriving mode
  Changes and Fixes
  * New memory model for packet contents
  * New pooled memory for packet contents
  * New packet data handling
  * New IPC & remote capture protocol
  * New pooled memory for tracked components
  * New dynamic element contents
  * Optimized Adler32 checksums
  * Update robinhood hash and transition more pools to it
  * Reworked kismetdb database writing
  * Squeeze more memory out of tracked components
  * Fix Linux monitor mode creation
  * Faster packet deduplication
  * Better BTLE support
  * Fixes for some GPS behavior
  * Better handling of proxied subdirectories
  * Lots of threading fixes
  * Latest boost/asio/beast
  * Fixes to ADSB lookups
- Add patch to fix the build of the alertsyslog plugin:
  * 0001-Update-FetchGlobal-usage.patch
* Sat Aug 21 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2021-08-R1
  Changes and Updates
  * UTF8/Unicode support in the UI
  * New WIDS alerts
  * Kismet now detects the VDOO RTL8170C exploits, and "funny"
    SSIDs that attack Apple products.
  * Small tweaks and improvements
  * Wigle CSV files now encode the Kismet version in the upload.
  * Client names are used in AP lists.
  * Initial support for environmental sensors connected to Kismet.
  * ticc2540/2531 udev rules.
  * Minor revamping of websocket timeouts.
  * Regex filtering added to the wiglecsv converter.
  * Quick copy-to-clipboard buttons for some common fields in
    the UI.
  Bug fixes
  * Handle URI parameters more correctly
  * Don’t spin on "Loading..." in the datasource window sometimes.
- Update to version 2021-06-R1
  Bug fixes
  * Another huge change to the threading model.
  * Fix kismetdb_to_pcap on older kismetdb logs.
  * Detect version properly in kismetdb_to_pcap and query the tags
    field properly on older logs.
  * Handle db versions properly in kismetdb_to_wiglecsv.
  * Detect version properly in kismetdb_to_wiglecsv and query
    fields properly.
  * Handle nested WHERE in sqlite bridge.
  * Handle nested WHERE queries properly and detect malformed
    queries in the sqlite3 bridge.
  * Fix kismetdb_to_wiglecsv Bluetooth.
  * Handle the nested WHERE for Bluetooth devices in wiglecsv
    correctly.
  * Other minor bugfixes to errors, terminology, etc.
- Update to version 2021-05-R1
  Changes and Updates
  * New mutex and threading.
  * Multi-core packet decoding.
  * New 802.15.4 phy.
  * 802.15.4 is now decoded and displayed in the UI! While many
    devices report the default PAN of 0x00, it’s still a huge
    step forward!
  * New data capture drivers for the Nuand BladeRF2 with Wiphy
    firmware, the nrf52840 802.15.4 hardware, and killerbee
    802.15.4 hardware.
  * New alert UI.
  * Alerts now have their own top-level panel and are searchable,
    sortable, and have priorities assigned to them.
  * Fix Wi-Fi on Linux 5.10 and newer.
  * The Linux kernel changed how netlink messages are fragmented,
    which broke how channels were indexed. Most likely this would
    show up when you had a number of Wi-Fi interfaces plugged in
    at once. This is fixed now.
  * PcapNG GPS logging.
  * New custom blocks and attributes in PcapNG logs for
    GPS logging.
  * Shift to officially requiring C++14 .
  * Support older libwebsockets.
  * Support ADSB HEX export per-source.
  * Fix datasources in error state getting into weird loops.
  * Datasoruces flapping in some error states (such as devices
    being unplugged) could get into weird states where the UUID
    would flap; this confused the logs, the datasources UI, and
    other spots. Properly retain the UUID.
  * Fix datasources getting into a no-channels state.
  * Some combinations of errors could lead to datasources getting
    into a state with no channels, and never being able to get out
    of it.
  * Fix Wi-Fi pulling WEXT legacy channels.
  * Default to WEXT IOCTL legacy channels when netlink fails or
    returns no channels, resolve wext channel frequencies to
    channel names.
  * Fix several thread contention errors on data.
  * Several objects were shared for serialization and not properly
    protected, leading to subtle corruption or outright crashes at
    times. Those are now removed from the combined APIs or properly
    protected.
  * Better error handling for TI-CC-2531 and TI-CC-2540 .
  * Handle soft-resets of the TI-CC-2531 and 2540 802.15.4 and
    BTLE chipsets gracefully, so there are fewer errors and resets
    of the hardware.
  * Add Bluetooth and BTLE to Wigle exports.
  * Adding a /&censor=1 to the Kismet web UI will censor all
    location and mac addresses (to the best of its ability),
    making it easy to take screenshots.
  * The new webserver broke CORS negotiation. Fixed.
  * Smarter handling of HT/VHT IE tags.
  * Fix error timer initialization in datasources.
  * Don’t accidentally kill other timers anymore.
  * Add new WIDS signatures.
  * Detect CVE-2020-9395.
  * Fix up HTTP header connection states.
  * Add fetch device, monitor device, mac search APIs.
  * Fix eventbus websocket errors.
  * Expand buffer sizes for remote and IPC capture, this improves
    stability significantly on some platforms.
  * Many more smaller bugfixes throughout.
  * General improvements and changes to the REST API.
* Sun Feb 28 2021 Bernhard Wiedemann <bwiedemann@suse.com>
- Update kismet-fix-build.patch to drop build date again (boo#1047218)
* Mon Dec  7 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2020-12-R3
  * A bugfix release which solves a possible infinite loop until
    crash due to how GCC handles C++ templates differently than
    Clang.
* Sat Dec  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2020-12-R2
  * Fix improper assignment of system endpoints to the logon
    role instead of read-only
  * Fix broken implementation of legacy TCP remote capture on
    python-based sources
* Fri Dec  4 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2020-12-R1
  Release Highlights:
  * All new ASIO networking model
    + Kismet now uses the C++ ASIO networking library.
  * All new web server implementation (drop libmicrohttpdd)
  * New role based REST API
  * Remote capture over websockets
  * Huge RAM savings
  * Stability improvements
  * Higher performance web UI
  * New websocket APIs
  * Better location averaging
  * Improved channel and signal mapping
  * Improved 802.11 WDS handling
  * General improvements and changes to the REST API
  See https://www.kismetwireless.net/release/kismet-2020-12-R1/ for
  the full changelog.
* Sat Sep 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2020-09-R4
  * Fix a false “login required” error on the datasources panel.
* Sun Sep 20 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2020-09-R3
  * Properly show messages from datasources
  * Properly show error and status messages from opening
    datasources, which previously were ignored. This should make
    seeing errors opening datasources much easier.
  * Fix bluetooth capture on some platforms
  * Some platforms / kernels / setups appear to not enable rfkill.
    The bluetooth hci capture source erroneously failed when no
    rfkill information was available.
  * Remove 221 IE tag subtype match requirement
  * Remove requiring a subtype of 0 on an IE221 tag for matching
    the manufacturer of otherwise unknown devices.
  * Fix potential crash in datasource panel
  * Fix a long-standing potential crash when the datasource panel
    is open in the UI caused by a race condition with the
    constructor and callbacks.
  * Fix race condition in launching datasources
  * Fix a long-standing race condition which could lead to some
    datasources not being opened properly or their types
    autodetected properly due to a race condition with the type
    probe code.
  * Increase precision of some doubles in JSON for GPS
  * Found some legacy serialization code which reduced the
    precision of some doubles (double-vector) which would cause
    GPS to display with less precision.
  * Don’t shut down messagebus processing thread until Kismet is
    fully exiting
  * The messagebus service thread could shut down before Kismet
    had finished spinning down, causing it to not show some of
    the errors causing the shutdown.
  * Fix moodycamel fast queue for gcc 9.2.0
  * Merge fix from cameron314/moodycamel to the fast concurrent
    queue library for compiling on gcc 9.2.0
  * Add new device locking API
  * Add new device locking API for internal range locking of
    devices to better protect records during updates between
    threads.
* Sun Sep 13 2020 Martin Hauke <mardnh@gmx.de>
- Add patch:
  * kismet-fix-build.patch (revert 3c8f8d83)
- Update to version 2020-09-R2
  * Save more RAM!
  * Fix a very silly error in kismetdb_dump_devices
  * The kismetdb_dump_devices tool was broken and printed out
    the JSON twice, generating an invalid JSON file.
  * Tweak how IE221 manufacturers are derived
  * Look for some specific AP manufacturers in the IE221 tags, and
    then fall back to using generic 221 manufacturers.
  * Fix packet RRD in main device table
  * Fix the packet RRD in the main device table not scrolling
    properly
  * Generally clean up compiling and squash a number of warnings
    during compiling
  * Fix a bug classifying some devices as APs
  * Some devices doing an inter-ds communication (like a chromecas
    and a phone) got flagged as APs when they’re not really.
- Update to version 2020-09-R1
  * Kismet server auto-discovery
  * New SSID details window to go along with the SSID views
  * New “MAC censorship” demo option in the web UI
  * Split advertised and responded APs
  * Significant memory optimizations
  * New optimized internal field building
  * Optimized “multikey-as-dictionary” API
  * Verbose output on remote capture tools
  * Expanded ICAO databases for ADSB
  * Compressed server-side ICAO databases
  * More memory control options
  * New greatly simplified JSON generation and parsing
  * Support for non-packet scan reports
  * New event bus extension to the Kismet helper protocol
  * New kismetdb_to_pcap tool
  * Configuration flavors/override system
  * Packet rate graphs
  * More manufacturer indexing
  * Optimized internal map structure
  * Lots and lots of bug fixes and minor updates
* Sun May  3 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2020-04-R3
  * fix a possible crash in Kismet and associated tools when
    compiled with GCC; there are no other changes.
* Thu Apr 23 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2020-04-R2
  * Bugfix release
* Tue Apr 21 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2020-04-R1
  * New web-based UI with searching, device notes, realtime
    graphs, and more.
  * A REST-like API
  * Expanded support for non-WiFi capture types
  * New remote capture
  * Massive data set support
  * New KismetDB logs
  * Multithreaded optimizations
  * Kismet will now take advantage of multi-core systems, both on
    large servers, and on small systems like the Raspberry Pi;
  * Live packet export
  * Packets can now be streamed live via the export endpoints, as
    a pcapng stream of all packets or with live filtering by data
    source, device, and more.
  * Scriptable alerts
  * Alerts can be defined (and triggered) via REST endpoints
* Sun Mar 29 2020 ecsos@opensuse.org
- Install plugin alertsyslog.
* Mon Mar  9 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2020-03-R1
  Bugfix release
  * RTL433 changing command line arguments
  * Extreme memory use compiling bluetooth_ids code
  * Fixes to kismetexternal python code used by rtladsb and rtlamr
  * Fixes to handling “weird” rtl433 serial numbers, like 000000001
  * Fixes for ubertooth remote cap
  * Updates to the kw41z capture code
  * Support for multiple phys on a single interface
  * Fix for buffer size calculation which could impact gps handling
  * Smarter error handling with channel tuning failures
  * Support for CORS cross-side negotiation for running Kismet
    behind a proxy
- Introduce new subpackages
  * kismet-capture-ti-cc-2531
    + TICC2531 802.15.4 Zigbee Sniffer capture helper
  * kismet-capture-nrf-nxp-kw41z
    + NXP KW41Z BTLE and Zigbee Sniffer capture helper
* Sun Jan  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2019-12-R2
  A bugfix release for Kismet 2019-12, R2 solves a number of quirks
  which were quite annoying:
  * Solve a race condition in Linux with interface naming. Due to
    how the nl80211 layer handles interface naming, combined with
    how systemd can name interfaces on some systems, it was
    possible to have a race condition when Kismet defaulted to
    kismonX interface names, resulting in either errors or Kismet
    ignoring one of the interfaces.
  * Solve a free on an unused pointer in nl80211 vif creation. The
    new vif creation code doesn’t use the nl80211 flags
    sub-message when there are no flags to add, but tried to free
    it. This could cause a crash the first time trying to open a
    source, but the second time would succeed.
  * Fix TICC2540 USB devices. Some systems were very unhappy with
    the order in which the USB device was initialized; now it
    should be fine.
  * Work around the very broken RTL8812BU driver. While we don’t
    recommend this driver or these cards, due to a HUGE number of
    issues, Kismet will now do its best to open one and get it
    into monitor mode.
  * Much smoother operation with very very large numbers of
    sources. A side effect of the vif naming fix, interfaces are
    now initialized and opened one at a time. While this may take
    much longer to open huge numbers (dozens or more) of
    interfaces, it is much more reliable and much less likely to
    cause Kismet or kernel problems during the initial bring-up
    and firmware load of interfaces.
  * Minor output text fixes. Capture interface and base
    interface were swapped in some messages to the user.
* Wed Dec 25 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2019-12-R1
  Bugfixes and performance boosts
  * Remove OpenMP/parallel processing; this resolves a massive
    CPU burn on even moderate numbers of devices.
  * Fix logging bug causing export of all devices every logging
    cycle, instead of only modified and new devices.
  * Revamped python-kismet-external using asyncio to prevent a
    large CPU wasting IO loop.
  * Bugfixes to the Linux netlink monitor controls to prefer
    nl80211, find existing monitor interfaces correctly, and to
    work on devices that don’t support IOxIWCTL iocontrols at all
    (AX200).
  * Switch to std::unordered_map hash maps for O(1) lookups
    whenever possible
  New features
  * BTLE packet capture and basic device display, using the
    aUbertooth One, CC2540, or nRF51822;
  * New SDR demodulators for ADSB (airplane) and AMR (power and
    water meter) with no external dependencies beyond librtlsdr
    and python3!
  * New ADSB mapping UI
  * BTLE support in the UI
  * New formatting options for ekjson to simplify export to other
    tools
  * Device present/missing alerts
  * ADSB geolocation
  * Detection of CVE-2019-17666 RTLWIFI vulnerabilities
* Sun Dec  1 2019 Martin Hauke <mardnh@gmx.de>
- Completely rewritten spec-file
- Intruduce subpackages for the capture helpers
- Add kismet-rpmlintrc
- Package systemd service file
- Remove obsolete patch:
  * kismet-2011-03-R2-makefile.diff
- Update to version 2019-09-R1
  This is the new, MAJOR rewrite of Kismet! This version changes
  almost everything, hopefully for the better, including:
  * Web-based UI allowing for much simpler presentation of data
    and compatibility with mobile devices
  * Standard JSON-based data export for easy scripting against
    Kismet instances
  * Support for wireless protocols beyond Wi-Fi, like basic
    Bluetooth scanning, thermometer, and weather station detection
    with the RTL-SDR hardware, and more on the way
  * New remote-capture code optimized for binary size and RAM,
    allowing extremely low-end embedded devices to be used for
    packet capture
  * New logging format which can encapsulate complex information
    about devices, system state, alerts, messages, and packets in a
    single file with simple tools for extracting standard formats
  * Pcap-NG multi-interface logs with complete original headers,
    readable by Wireshark and other tools
* Tue Jul  5 2016 mardnh@gmx.de
- Kismet 2016-07-R1:
  * nl8011 support is fixed so finding the vif device works again
  * full 5GHz channel discovery works now
  * memory leaks in the drone are fixed
  * some ncurses compile bugs are resolved
* Wed Apr 13 2016 astieger@suse.com
- Kismet 2016-01-R1:
  * force validation of fcs by default for all sources
  * support for recent autotools
  * fixes for crashes when alert backlog was set to zero
  * fixes for failures in some VIF situations
  * fixes to resizing windows
  * fixes to GPS averaging
  * fixes to Radiotap changes in recent kernels
  * add WPS state parsing
  * handle BSSTimestamp parsing
- upstream sources no longer signed, use source URLs
* Wed Sep 17 2014 andreas.stieger@gmx.de
- Require xz
* Tue May 27 2014 crrodriguez@opensuse.org
- version 2013-03-R1b
  * While this does not have major new features
  (phy-neutral is still in development)
  it includes a long list of bugfixes,
  including better ncurses color support, radiotap fixes,
  better interface control when setting channels, memory leak fixes,
  better packaging for distros, and various other quirks.
- Switch build to libnl3.
* Fri May 31 2013 coolo@suse.com
- do not hardcode automake 1.12
* Sat Feb 23 2013 andreas.stieger@gmx.de
- Verify GPG signature only for 12.3 and up, fixing 12.2 build
- verify in prep section, and only if macro is available
* Wed Nov 28 2012 sbrabec@suse.cz
- Verify GPG signature.
* Thu Jul 19 2012 dvaleev@suse.com
- fix ppc64 build
* Wed Sep 28 2011 meissner@suse.de
- Kismet-2011-03-R2 released, includes:
- 2011-03-R2
  New release to address a crash bug in Kismet when operating as a drone
  (either kismet_server or kismet_drone).
- 2011-03-R1
  fixes problems with changes in ncurses 5.8 (for the few
  distributions which picked it up already) and is REQUIRED for Kismet
  to work with ncurses-5.8.  Also introduced is marginally more accurate
  GPS averaging (still all the problems of weighting and averaging,
  but eliminates the float drift), some compile time updates, other
  minor tweaks.
  Under the covers 2011-03 also contains the start of the new phy-neutral
  common tracker layer, which will be replacing the current model of an
  802.11-centric tracking layer.  Anyone working on capture plugins for
  non-dot11 protocols should start taking a look at the new tracking
  layer.  The dot11 tracking is being ported to the new layer and
  eventually they old tracking code will be disabled.
- 2011-01-R1
  Lots of bugfixes (netxml reference, 802.11d, mac80211 on legacy cards,
  client preferences, client display options)
  Ruby network API and example clients
  Wifi NIC performance shoot-out tool
  WPA Migration Mode detection
  GPS logging in PPI pcap files
  Per-capture source per-network and per-client signal tracking
  Packaging scripts
- 2010-07-R1 changes:
  Enhancements:
  Ruby interface and examples
  Proper TCP Async (for large numbers of drones and other situations)
  Add hidedata= option for "safer" sniffing in public environments
  Kluged escape handler for broken ncurses arrow handling on some systems
  Add --no-root option for zero-priv drone-only deploys
  Bugfixes:
  Fix installation on Ubuntu dash
  IPC updates and fixes for drone
  IPC architectural fixes
* Tue Sep 27 2011 idonmez@suse.com
- Cleanup spec file and fix build for < openSUSE 12.1
* Fri Sep 16 2011 jengelh@medozas.de
- Select libnl-1_1-devel
* Thu Apr 15 2010 meissner@suse.de
- Kismet-2010-01-R1 released, includes
  - fixes to segfaults
  - compiling problems on Snow Leopard
  - GPS, and sundry other quirks
  - and enhancements to the UI
  - support for the new GPSD JSON-only protocol
  - and a BT scanning plugin for BT device discovery.
- Kismet-2009-11-R1 released, Release includes:
  - fixes to crashes on resizing terminals
  - tweaks to plugins
  - addition of the autowep plugin
  - improved plugin handling
  - plugin support on OSX
  - initial support for Snow Leopard
  - fixes to PPI corruption
  - XML fixes
  - and quite a lot of other bugfixes.
* Wed Aug 26 2009 meissner@suse.de
- buildrequire pcre-devel and libnl-devel added to enable
  more features.
* Wed Aug  5 2009 prusnak@suse.cz
- updated to 2009-06-R1
  * Restore battery/power reporting functionality
  * Default to VAP creation on mac80211 sources
  * Revamp IP range guessing
  * Added mouse support for network and client lists
  * Properly handle PHY packets
  * Fix filter string parsing for double-negate
  * Add low-level mac80211 control options for FCS and PLCP failure filtering
  * Added arbitrary tagging strings to clients
  * Add preserved tagging (~/.kismet file)
  * Restored linux-cap dropping on capture
  * Handle sources being disconnected under some libpcap versions
  * Restored daemonize
  * Revamped network details text
  * Restored decloaked SSID caching
  * Add plugin API for adding menus
  * Improved Nokia ITT support
  * Restore missing alerts
  * Added "user notes" to networks and clients
  * Various and sundry UI usability changes
  * Multiple crashes, internal inconsistencies, and rare but unpleasant bugs fixed
* Tue Jun  9 2009 coolo@novell.com
- fix build with glibc 2.10
* Mon Jan  5 2009 mseben@suse.cz
- added libexpat-devel to BuildRequires (needed to build gpsmap)
  [bnc#462695]
* Mon Jan  5 2009 mseben@suse.cz
- added libexpat-devel to BuildRequires (needed to build gpsmap)
  [bnc#462695]
* Mon Sep  1 2008 ro@suse.de
- add ncurses include path to cflags
* Wed Jul  9 2008 prusnak@suse.cz
- updated to 2008-05-R1
  * wrt54 fixes
  * Multiple Darwin fixes
  * GPS rewrite and fixes
  * Nokia tweaks
  * Imagemagick fixes
  * More wrt54 prism0 hacks
  * Tweaked the wrt54 stuff more (where does prism0 come from?)
  * Tweaked wrt54 source
  * Added configure patch for OSX and debian control files from
    Evan Broder
  * Fixed imagemagick detect on modern IM installs
  * Added gpsmap patches from Kripton to support open street maps
  * Added DLT80211 and DLT80211_AVS to the linktype setting code
    on Darwin, BSD
  * Added 'kismet' wrapper binary, conf files to clean/distclean
  * Fixed assorted messages being printed in quiet mode
  * Added additional warnings/info for madwifi-ng about autocreate=none
    when other vaps are found.
  * Removed wlancond/power setting on Maemo/Nokia since it doesn't seem
    to reliably help
  * Merged patches from Alexandre Balavas to clean up warnings on CentOS
  * Re-ordered headers in panelfront_display to prevent weird compiler issue
    on Darwin
  * Fixed gpsd speed issue on water mode, thanks again to Antonio
  * Fixed segv on gps=false introduced in recent gps rewrite
    (thanks Antonio Eugenio Burriel for patch)
  * Added rt61 and rt8187 source names
  * Fixed segv on OSX in client on closedir
  * Revamped GPS to use 'watch' mode in GPSD
  * Revamped GPS again to work with watch better and to dynamically use poll
    mode on older GPSD implementations
  * Revamped GPS a third time in the same day to take the seemingly broken Maemo
    GPSD into account and use R=1 debug mode on Maemo devices
  * Added Hildon GPS support
  * Fixed huge bug in IE tag parsing that ignored large beacon frames,
    thanks to Duane Compton
  * Disabled probenojoin by default in config, it's sort of a useless alert
    which makes a lot of noise.
  * More capture source control changes to try to solve problems capturing reliably
    on Nokia 8x0 devices
  * Nokia-specific changes
  * Added kernel version detection for Darwin to accept enX on >= Leopard,
    VERY NEW LIBPCAP required.
  * Fixed admtek fatal error on ssid zero (errors now ignored)
  * Fixed a problem where the first connection to the server would be ignored.
  * Merged a patchset from Pavol Rusnak and SUSE including some ncurses cleanups,
    format string quirks with size_t, and header massaging
  * Fixed 'make install' and 'make suidinstall' not dep'ing 'kismet' binary
  * Added --disable-dbus to configure for environments which don't detect properly
- fixed return of random data from nonvoid function (nonvoid.diff)
- removed obsoleted patches:
  * bool.diff (included in update)
  * includes.diff (included in update)
  * intptr.diff (included in update)
  * wtap.diff (included in update)
* Thu Feb 21 2008 crrodriguez@suse.de
- correct buildrequires after wireshark-devel changes
- only link with the needed libraries
* Mon Feb 11 2008 schwab@suse.de
- Fix crash on exit.
* Tue Dec  4 2007 prusnak@suse.cz
- fixed missing includes (includes.patch)
* Wed Oct 31 2007 prusnak@suse.cz
- update to 2007-10-R1
  * basic 802.11N support
  * Airpcap 11n header support
  * DBUS support for controlling NetworkManager
  * significant memory reduction in server/client
  * significantly faster client code
  * D80211 device support (iwl, others)
  * revamped madwifi-ng support
  * GPSD anti-jitter handling
  * innumerable bug fixes
  * see CHANGELOG for more details
* Fri Sep 21 2007 schwab@suse.de
- Update BuildRequires.
* Fri Mar 30 2007 dmueller@suse.de
- update buildrequires
* Tue Feb 27 2007 dmueller@suse.de
- reduce buildRequires
* Thu Feb  8 2007 prusnak@suse.cz
- upgraded to 2007-01-R1b
  * added Nokia 770/800 support
  * added multiple IDS alerts
  * fixed memory mismanagement crashes
- fixed spec file and makefile.diff for #norootforbuild
* Mon Jul 17 2006 mskibbe@suse.de
- update to version 2006_04 which
  o contains patch:
    kismet-2005-08-R1-madwifi-ng.diff
    kismet-2005-08-R1-bcm43xx.diff
    kismet-2005-08-R1-prism2.diff
    kismet-2005-08-R1-svn.diff
  o Added --retain-monitor cmdline option on request
  o Added setting madwifi-ng to radiotap mode
  o Added the initial ipw3945 madwifi-ng support
  o Added zd1211 capture source (with warnings)
  o Added memset 0 to gpsd code to explicity zero the gps data
  o Added a fix to ringbuf from Shane Schisler
  o Added extremely experimental support for broadcom 43xx
  o Fixed several crashes due to not checking noise/junk
  o Fixed madwifi-ng fcs bytes
  o Fixed madwifi-ng not shutting down rfmon vap
  o Fixed madwifi_ag with madwifi-ng drivers
  o Moved ipw3945parasite to ipwlivetap
  o Moved madwifing support into madwifi standard as an auto-detect
  o Switched ACX100 capture to not expect the FCS bytes
    buffer on startup
  o Changed prism2 header conversion to ignore a broken length
    field in the header
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 24 2006 mjancar@suse.cz
- backports from svn
  * support for madwifi-ng (#136896)
  * support for bcm43xx
  * various bugfixes
* Sun Jan 22 2006 coolo@suse.de
- fixed crash (and avoid stripping)
* Sat Jan 14 2006 kukuk@suse.de
- Add gmp-devel to nfb
* Thu Jan 12 2006 mjancar@suse.cz
- compile with -fstack-protector
* Fri Oct  7 2005 schwab@suse.de
- Fix last change.
- Fix more format string bugs.
- Fix infinite loop.
* Fri Oct  7 2005 yxu@suse.de
- complete missing parameter for function fprintf
* Mon Aug 29 2005 ro@suse.de
- added ethereal-devel to nfb
* Mon Aug 29 2005 mjancar@suse.cz
- update to 2005-08-R1
  * fix heap overflow (#106134)
* Thu Jul 28 2005 mjancar@suse.cz
- update to 2005-07-R1a
* Tue Apr 12 2005 mjancar@suse.cz
- upgrade to 2005-04-R1
- fix for gcc 4.0
* Wed Oct 27 2004 meissner@suse.de
- Upgraded to 2004-10-R1:
  Some fixup to gpsd handling (More to come)
  GCC-3.4 cleanups
  BSS Timestamp alerts
  Centrino support, support for GPL ADMTek drivers,
  Support for alternate cisco drivers
  Imagemagick support for new imagemagick api changes
  Expanded alert protocol to carry additional info about the environment
  that generated the alert
  Fixed packet number and delta calculations, and sound output for
  traffic seen
  Fixed crankiness with hostap if interface is down
  Added default "no-type" card to force new users to configure
  Lots of other bug fixes
  WSP100 is known to be broken in this release
* Tue Aug 31 2004 meissner@suse.de
- fixed problem with new ImageMagick.
* Wed Aug 18 2004 meissner@suse.de
- Add README and CHANGELOG to documentation.
* Mon Jul 26 2004 meissner@suse.de
- Upgraded to 2004-04-R1 release. (new features, lots of bugfixes, etc ...)
- Fixed C++ problem which caused endless loops on 64bit. #43108
- Made gpsmap build.
* Fri Feb 13 2004 meissner@suse.de
- Upgraded to feb.04.01 release. (new american naming scheme
  which will break RPM ordering).
* Mon Jan 26 2004 ro@suse.de
- undef bool after including ncurses
* Fri Aug  8 2003 meissner@suse.de
- updated to 3.0.0
* Mon Jul 28 2003 meissner@suse.de
- /usr/bin/convert now needs libexif, added to nfb
* Fri Jul 25 2003 meissner@suse.de
- make build on ppc64, fixed configure.in problems.
* Mon Jul 21 2003 meissner@suse.de
- apply cast to fix 64bit problem.
- fixed default config files to use /usr/ instead of /usr/local/
* Fri Jul 18 2003 meissner@suse.de
- package created with version 2.8.1.
